﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.CodeDom;
using System.Web.Services;
using Telerik.Web.UI;
using System.Data;
using System.Collections;

partial class _Default : System.Web.UI.Page
{
    protected void Page_Init(object sender, System.EventArgs e)
    {
        DefineGridStructure();
    }
    protected void Page_Load(object sender, System.EventArgs e)
    {
        Label1.Text = "";
    }
    private void DefineGridStructure()
    {
        //Create and set the grid
        RadGrid grid = new RadGrid();
        grid.ID = "RadGrid1";
        grid.Skin = "Default";
        grid.Width = Unit.Percentage(100);
        grid.PageSize = 5;
        grid.AllowPaging = true;
        grid.PagerStyle.Mode = GridPagerMode.NextPrevAndNumeric;
        grid.AutoGenerateColumns = false;
        grid.MasterTableView.CommandItemDisplay = GridCommandItemDisplay.Top;
        grid.MasterTableView.EditMode = GridEditMode.PopUp;
        grid.AutoGenerateEditColumn = true;
        grid.NeedDataSource += new GridNeedDataSourceEventHandler(grid_NeedDataSource);
        grid.InsertCommand += new GridCommandEventHandler(RadGrid1_InsertCommand);
        grid.UpdateCommand += new GridCommandEventHandler(RadGrid1_UpdateCommand);
        grid.ItemCreated += new GridItemEventHandler(grid_ItemCreated);

        //Set MasterTableView
        grid.MasterTableView.PageSize = 15;
        grid.MasterTableView.Width = Unit.Percentage(100);
        grid.MasterTableView.DataKeyNames = new string[] { "ID" };

        //Add columns
        GridBoundColumn boundColumn = new GridBoundColumn();
        boundColumn.ReadOnly = true;
        boundColumn.DataField = "ID";
        boundColumn.HeaderText = "ID";
        grid.MasterTableView.Columns.Add(boundColumn);
        boundColumn = new GridDateTimeColumn();
        boundColumn.DataField = "DateColumn";
        boundColumn.HeaderText = "DateColumn";
        boundColumn.DataFormatString = "{0:dd/MM}";
        grid.MasterTableView.Columns.Add(boundColumn);

        // Add the grid to the placeholder
        this.PlaceHolder1.Controls.Add(grid);
    }

    void grid_ItemCreated(object sender, GridItemEventArgs e)
    {
        //Set the column editor
        if (e.Item is GridEditableItem && e.Item.IsInEditMode)
        {
            GridEditableItem item = e.Item as GridEditableItem;
            RadDatePicker picker = item["DateColumn"].Controls[0] as RadDatePicker;
            picker.DateInput.DateFormat = "dd/MM";
            picker.DateInput.DisplayDateFormat = "dd/MM";
        }
    }

    void grid_NeedDataSource(object source, GridNeedDataSourceEventArgs e)
    {
        (source as RadGrid).DataSource = GetData;
    }

    protected DataTable GetData
    {
        get
        {
            DataTable table = Session["Table"] as DataTable;
            if (table == null)
            {
                table = new DataTable();
                table.Columns.Add("ID", typeof(Int32));
                table.Columns.Add("DateColumn", typeof(DateTime));
                table.Columns["DateColumn"].AllowDBNull = true;
                for (int i = 0; i < 10; i++)
                {
                    if (i % 2 == 0)
                    {
                        table.Rows.Add(i, DateTime.Now.AddDays(i));
                    }
                    else
                    {
                        table.Rows.Add(i, null);
                    }
                }
                Session["Table"] = table;
            }
            return table;
        }
        set
        {
            Session["Table"] = value;
        }
    }

    private void RadGrid1_InsertCommand(object source, Telerik.Web.UI.GridCommandEventArgs e)
    {
        GridEditableItem editedItem = e.Item as GridEditableItem;
        DataTable table = this.GetData;
        DataRow newRow = table.NewRow();
        DataRow[] allValues = table.Select("", "ID", DataViewRowState.CurrentRows);
        if (allValues.Length > 0)
        {
            newRow["ID"] = (int)allValues[allValues.Length - 1]["ID"] + 1;
        }
        else
        {
            newRow["ID"] = 1;
        }
        Hashtable newValues = new Hashtable();
        e.Item.OwnerTableView.ExtractValuesFromItem(newValues, editedItem);
        try
        {
            foreach (DictionaryEntry entry in newValues)
            {
                if (entry.Value == null)
                {
                    newRow[(string)entry.Key] = DBNull.Value;
                }
                else
                {
                    newRow[(string)entry.Key] = entry.Value;
                }
            }
            table.Rows.Add(newRow);
            Label1.Text += "ID " + newRow["ID"] + " inserted!";
        }
        catch (Exception ex)
        {
            Label1.Text += "Unable to insert into ID. Reason: " + ex.Message;
            e.Canceled = true;
        }


    }
    protected void RadGrid1_UpdateCommand(object source, Telerik.Web.UI.GridCommandEventArgs e)
    {
        GridEditableItem editedItem = e.Item as GridEditableItem;
        DataTable table = GetData;
        //Locate the changed row in the DataSource
        DataRow[] changedRows = table.Select("ID = " + editedItem.OwnerTableView.DataKeyValues[editedItem.ItemIndex]["ID"].ToString());
        if (changedRows.Length != 1)
        {
            this.Label1.Text += "Unable to locate the ID for updating.";
            e.Canceled = true;
            return;
        }
        //Update new values
        Hashtable newValues = new Hashtable();
        e.Item.OwnerTableView.ExtractValuesFromItem(newValues, editedItem);
        changedRows[0].BeginEdit();
        try
        {
            foreach (DictionaryEntry entry in newValues)
            {
                if (entry.Value == null)
                {
                    changedRows[0][(string)entry.Key] = System.DBNull.Value;
                }
                else
                {
                    changedRows[0][(string)entry.Key] = entry.Value;
                }
            }
            changedRows[0].EndEdit();
            Label1.Text += "ID " + changedRows[0]["ID"] + " updated!";
        }
        catch (Exception ex)
        {
            changedRows[0].CancelEdit();
            Label1.Text += "Unable to update table. Reason: " + ex.Message;
            e.Canceled = true;
        }
    }
}








